@@ -1,5 +1,3 @@
-{-# LANGUAGE ScopedTypeVariables #-}
-
 import Data.Yaml (decodeFileEither, decodeEither')
 import System.Environment (getArgs)
 import System.Exit
@@ -11,18 +9,18 @@ import Data.ByteString (getContents)
 helpMessage :: IO ()
 helpMessage = putStrLn "yaml2json FILE\n  use - as FILE to indicate stdin" >> exitFailure
 
+showJSON :: Show a => Either a Value -> IO b
 showJSON ejson =
     case ejson of
        Left err -> print err >> exitFailure
-       Right (res :: Value) -> putStr (encode res) >> exitSuccess
+       Right res -> putStr (encode (res :: Value)) >> exitSuccess
 
 main :: IO ()
 main = do
     args <- getArgs
     case args of
-       [] -> helpMessage
-       (f:a:_)  -> helpMessage
        -- strict getContents will read in all of stdin at once
-       ("-":[]) -> getContents >>= showJSON . decodeEither'
-       (f:[])   -> decodeFileEither f >>= showJSON
+       (["-"]) -> getContents >>= showJSON . decodeEither'
+       ([f])   -> decodeFileEither f >>= showJSON
+       _ -> helpMessage
        
